@@ -9,7 +9,7 @@
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2024 Eggheads Development Team
+ * Copyright (C) 1999 - 2025 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -88,8 +88,7 @@ void addbot(char *who, char *from, char *next, char flag, int vernum, int ssl)
     ptr = &((*ptr)->next);
   }
   ptr2 = nmalloc(sizeof(tand_t));
-  strncpy(ptr2->bot, who, HANDLEN);
-  ptr2->bot[HANDLEN] = 0;
+  strlcpy(ptr2->bot, who, sizeof ptr2->bot);
   ptr2->share = flag;
   ptr2->ver = vernum;
   ptr2->next = *ptr;
@@ -1418,6 +1417,8 @@ static void cont_tandem_relay(int idx, char *buf, int i)
   check_tcl_chof(dcc[uidx].nick, dcc[uidx].sock);
   dcc[uidx].type = &DCC_RELAYING;
   dcc[uidx].u.relay = ri;
+  if (dcc[uidx].status & STAT_TELNET)
+    tputs(dcc[idx].sock, TLN_IAC_C TLN_DO_C TLN_STATUS_C, 3);
 }
 
 static void eof_dcc_relay(int idx)
@@ -1436,7 +1437,7 @@ static void eof_dcc_relay(int idx)
   dcc[j].status = dcc[j].u.relay->old_status;
   /* In case echo was off, turn it back on (send IAC WON'T ECHO): */
   if (dcc[j].status & STAT_TELNET)
-    dprintf(j, TLN_IAC_C TLN_WONT_C TLN_ECHO_C "\n");
+    tputs(dcc[j].sock, TLN_IAC_C TLN_WONT_C TLN_ECHO_C, 3);
   putlog(LOG_MISC, "*", "%s: %s -> %s", BOT_ENDRELAY1, dcc[j].nick,
          dcc[idx].nick);
   dprintf(j, "\n\n*** %s %s\n", BOT_ENDRELAY2, botnetnick);
