@@ -2,7 +2,7 @@
 /*
  * inet_aton.c -- provides inet_aton() if necessary.
  *
- * Portions Copyright (C) 2000 - 2024 Eggheads Development Team
+ * Portions Copyright (C) 2000 - 2025 Eggheads Development Team
  */
 
 #include "main.h"
@@ -89,12 +89,8 @@ static const char rcsid[] = "$Id: inet_addr.c,v 1.5 2005/04/27 04:56:19 sra Exp
 #endif /* LIBC_SCCS and not lint */
 
 #include <sys/param.h>
-
-#include <netinet/in.h>
 #include <arpa/inet.h>
 
-#include <ctype.h>
-
 /*
  * Check whether "cp" is a valid ascii representation
  * of an Internet address and convert to a binary address.
@@ -106,8 +102,8 @@ int egg_inet_aton(const char *cp, struct in_addr *addr) {
   u_long val;
   int base, n;
   char c;
-  u_int8_t parts[4];
-  u_int8_t *pp = parts;
+  uint8_t parts[4];
+  uint8_t *pp = parts;
   int digit;
 
   c = *cp;
