@@ -4,7 +4,7 @@
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2024 Eggheads Development Team
+ * Copyright (C) 1999 - 2025 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -138,7 +138,7 @@ int logmodes(char *s)
   return res;
 }
 
-char *masktype(int x)
+const char *masktype(int x)
 {
   static char s[27];            /* Change this if you change the levels */
   char *p = s;
