@@ -7,7 +7,7 @@
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2024 Eggheads Development Team
+ * Copyright (C) 1999 - 2025 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -71,7 +71,7 @@
 #  define _POSIX_SOURCE 1               /* Solaris needs this */
 #endif
 
-extern char origbotname[], botnetnick[]; 
+extern char origbotname[], botnetnick[];
 extern int dcc_total, conmask, cache_hit, cache_miss, max_logs, quiet_save;
 extern struct dcc_t *dcc;
 extern struct userrec *userlist;
@@ -238,7 +238,7 @@ static int nested_debug = 0;
 static void write_debug()
 {
   int x;
-  char s[25];
+  char s[26];
 
   if (nested_debug) {
     /* Yoicks, if we have this there's serious trouble!
@@ -247,7 +247,7 @@ static void write_debug()
     x = creat("DEBUG.DEBUG", 0644);
     if (x >= 0) {
       setsock(x, SOCK_NONSOCK);
-      strlcpy(s, ctime(&now), sizeof s);
+      ctime_r(&now, s);
       dprintf(-x, "Debug (%s) written %s\n"
                   "Please report problem to https://github.com/eggheads/eggdrop/issues\n"
                   "Check doc/BUG-REPORT on how to do so.", ver, s);
@@ -275,8 +275,8 @@ static void write_debug()
   if (x < 0) {
     putlog(LOG_MISC, "*", "* Failed to write DEBUG");
   } else {
-    strlcpy(s, ctime(&now), sizeof s);
-    dprintf(-x, "Debug (%s) written %s\n", ver, s);
+    ctime_r(&now, s);
+    dprintf(-x, "Debug (%s) written %s", ver, s);
 #ifdef EGG_PATCH
     dprintf(-x, "Patch level: %s\n", EGG_PATCH);
 #else
@@ -575,7 +575,7 @@ static void core_secondly()
   }
   nowmins = now / 60;
   if (nowmins > lastmin) {
-    memcpy(&nowtm, localtime(&now), sizeof(struct tm));
+    localtime_r(&now, &nowtm);
     i = 0;
     /* Once a minute */
     ++lastmin;
@@ -599,10 +599,11 @@ static void core_secondly()
       check_botnet_pings();
 
       if (!miltime) {           /* At midnight */
-        char s[25];
+        char s[26];
         int j;
 
-        strlcpy(s, ctime(&now), sizeof s);
+        ctime_r(&now, s);
+        s[24] = 0;
         if (quiet_save < 3)
           putlog(LOG_ALL, "*", "--- %.11s%s", s, s + 20);
         call_hook(HOOK_BACKUP);
@@ -637,6 +638,9 @@ static void core_secondly()
             movefile(logs[i].filename, s);
           }
       }
+#ifdef TLS
+      verify_cert_expiry(0);
+#endif
     }
   }
 }
@@ -876,7 +880,7 @@ static void mainloop(int toplevel)
         if (strcmp(p->name, "eggdrop") && strcmp(p->name, "encryption") &&
             strcmp(p->name, "encryption2") && strcmp(p->name, "uptime")) {
           f++;
-          debug1("stagnant module %s", p->name);
+          putlog(LOG_MISC, "*", "stagnant module %s", p->name);
         }
       }
       if (f != 0) {
@@ -946,7 +950,7 @@ static void init_random(void) {
 int main(int arg_c, char **arg_v)
 {
   int i, j, xx;
-  char s[25];
+  char s[26];
   FILE *f;
   struct sigaction sv;
   struct chanset_t *chan;
@@ -979,13 +983,13 @@ int main(int arg_c, char **arg_v)
   egg_snprintf(egg_version, sizeof egg_version, "%s+%s %u", EGG_STRINGVER, EGG_PATCH, egg_numver);
   egg_snprintf(ver, sizeof ver, "eggdrop v%s+%s", EGG_STRINGVER, EGG_PATCH);
   strlcpy(version,
-          "Eggdrop v" EGG_STRINGVER "+" EGG_PATCH " (C) 1997 Robey Pointer (C) 1999-2024 Eggheads Development Team",
+          "Eggdrop v" EGG_STRINGVER "+" EGG_PATCH " (C) 1997 Robey Pointer (C) 1999-2025 Eggheads Development Team",
           sizeof version);
 #else
   egg_snprintf(egg_version, sizeof egg_version, "%s %u", EGG_STRINGVER, egg_numver);
   egg_snprintf(ver, sizeof ver, "eggdrop v%s", EGG_STRINGVER);
   strlcpy(version,
-          "Eggdrop v" EGG_STRINGVER " (C) 1997 Robey Pointer (C) 1999-2024 Eggheads Development Team",
+          "Eggdrop v" EGG_STRINGVER " (C) 1997 Robey Pointer (C) 1999-2025 Eggheads Development Team",
           sizeof version);
 #endif
 
@@ -1068,8 +1072,8 @@ int main(int arg_c, char **arg_v)
   dns_thread_head = nmalloc(sizeof(struct dns_thread_node));
   dns_thread_head->next = NULL;
 #endif
-  strlcpy(s, ctime(&now), sizeof s);
-  memmove(&s[11], &s[20], strlen(&s[20]) + 1);
+  ctime_r(&now, s);
+  s[24] = 0;
   putlog(LOG_ALL, "*", "--- Loading %s (%s)", ver, s);
   chanprog();
   if (!encrypt_pass2 && !encrypt_pass) {
@@ -1172,8 +1176,14 @@ int main(int arg_c, char **arg_v)
     dcc[term_z].sock = STDOUT;
     dcc[term_z].timeval = now;
     dcc[term_z].u.chat->con_flags = conmask | EGG_BG_CONMASK;
-    dcc[term_z].u.chat->strip_flags = STRIP_ALL;
     dcc[term_z].status = STAT_ECHO;
+    if (isatty(dcc[term_z].sock)) {
+      debug0("stdout is a tty");
+      dcc[term_z].status |= STAT_TELNET;
+    } else {
+      debug0("stdout is no tty");
+      dcc[term_z].u.chat->strip_flags = STRIP_ALL;
+    }
     strcpy(dcc[term_z].nick, EGG_BG_HANDLE);
     strcpy(dcc[term_z].host, "llama@console");
     add_hq_user();
