@@ -3,7 +3,7 @@
  * MD5 Message-Digest Algorithm (RFC 1321).
  *
  * Homepage:
- * http://openwall.info/wiki/people/solar/software/public-domain-source-code/md5
+ * https://openwall.info/wiki/people/solar/software/public-domain-source-code/md5
  *
  * Author:
  * Alexander Peslyak, better known as Solar Designer <solar at openwall.com>
@@ -28,7 +28,7 @@
 
 #include "src/main.h"
 
-#ifdef HAVE_OPENSSL_MD5
+#if (OPENSSL_VERSION_NUMBER < 0x30000000L) && defined(HAVE_OPENSSL_MD5)
 #  include <openssl/md5.h>
 #else
 
