@@ -4,7 +4,7 @@
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2024 Eggheads Development Team
+ * Copyright (C) 1999 - 2025 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -337,7 +337,7 @@ static void zapf_assoc(char *botnick, char *code, char *par)
         chanout_but(-1, chan, ASSOC_CHNAME_NAMED2, botnick, nick, par);
       }
     } else {
-      dprintf(LOG_DEBUG, "ASSOC: Channel number outside bounds\n");
+      dprintf(LOG_DEBUG, "ASSOC: Channel number outside bounds 0..%i\n", GLOBAL_CHANS);
     }
   }
 }
