@@ -3,7 +3,7 @@
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2024 Eggheads Development Team
+ * Copyright (C) 1999 - 2025 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,8 +20,6 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-#include <ctype.h>
-
 static struct flag_record user = { FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0 };
 static struct flag_record victim = { FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0 };
 
@@ -1472,10 +1470,10 @@ static void cmd_chaninfo(struct userrec *u, int idx, char *par)
 
 static void cmd_chanset(struct userrec *u, int idx, char *par)
 {
-  char *chname = NULL, answers[512], *parcpy;
-  char *list[2], *bak, *buf;
+  char *chname = NULL, answers[1024], *parcpy;
+  char *list[2], value[2], *bak, *buf;
   struct chanset_t *chan = NULL;
-  int all = 0;
+  int len, all = 0;
 
   if (!par[0])
     dprintf(idx, "Usage: chanset [%schannel] <settings>\n", CHANMETA);
@@ -1534,8 +1532,10 @@ static void cmd_chanset(struct userrec *u, int idx, char *par)
               return;
             }
           if (tcl_channel_modify(0, chan, 1, list) == TCL_OK) {
-            strcat(answers, list[0]);
-            strcat(answers, " ");
+            strlcpy(value, list[0], 2);
+            len = strlen(answers);
+            egg_snprintf(answers + len, (sizeof answers) - len, 
+                (len == 0) ? "%s" : " %s", list[0]);        /* Concatenation */
           } else if (!all || !chan->next)
             dprintf(idx, "Error trying to set %s for %s, invalid mode.\n",
                     list[0], all ? "all channels" : chname);
@@ -1562,7 +1562,7 @@ static void cmd_chanset(struct userrec *u, int idx, char *par)
           strcpy(parcpy, par);
           irp = Tcl_CreateInterp();
           if (tcl_channel_modify(irp, chan, 2, list) == TCL_OK) {
-            int len = strlen(answers);
+            len = strlen(answers);
             egg_snprintf(answers + len, (sizeof answers) - len, "%s { %s }", list[0], parcpy); /* Concatenation */
           } else if (!all || !chan->next)
             dprintf(idx, "Error trying to set %s for %s, %s\n",
