@@ -3,7 +3,7 @@
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2024 Eggheads Development Team
+ * Copyright (C) 1999 - 2025 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1318,6 +1318,48 @@ static int tcl_channel_modify(Tcl_Interp *irp, struct chanset_t *chan,
   module_entry *me;
 
   for (i = 0; i < items; i++) {
+    if (item[i][0] == '+' || item[i][0] == '-') {
+      if (check_tcl_chanset(chan->dname, item[i] + 1, item[i][0] == '+' ? "1" : "0")) {
+        if (irp) {
+          Tcl_ResetResult(irp);
+          Tcl_AppendResult(irp, "Channel setting ", item[i], " rejected by Tcl script", NULL);
+        }
+        return TCL_ERROR;
+      }
+    } else {
+      // otherwise invalid later, missing value
+      if (i < items - 1) {
+        int free_value = 0;
+        char *value;
+
+        if (!strncmp("need-", item[i], 5)) {
+          value = item[i + 1];
+        } else {
+          char *sep = strchr(item[i + 1], ' ');
+
+          if (sep) {
+            value = nmalloc(sep - item[i + 1] + 1);
+            strlcpy(value, item[i + 1], sep - item[i + 1] + 1);
+            free_value = 1;
+          } else {
+            value = item[i + 1];
+          }
+        }
+        if (check_tcl_chanset(chan->dname, item[i], value)) {
+          if (free_value) {
+            nfree(value);
+          }
+          if (irp) {
+            Tcl_ResetResult(irp);
+            Tcl_AppendResult(irp, "Channel setting ", item[i], " to ", value, " rejected by Tcl script", NULL);
+          }
+          return TCL_ERROR;
+        }
+        if (free_value) {
+          nfree(value);
+        }
+      }
+    }
     if (!strcmp(item[i], "need-op")) {
       i++;
       if (i >= items) {
@@ -2169,12 +2211,15 @@ static int tcl_channel_add(Tcl_Interp *irp, char *newname, char *options)
     ret = TCL_ERROR;
   }
   Tcl_Free((char *) item);
-  if (join && !channel_inactive(chan) && module_find("irc", 0, 0)) {
-    if (chan->key_prot[0])
-      dprintf(DP_SERVER, "JOIN %s %s\n", chan->dname, chan->key_prot);
-    else
-      dprintf(DP_SERVER, "JOIN %s\n", chan->dname);
-  }
+  if (ret == TCL_OK) {
+    if (join && !channel_inactive(chan) && module_find("irc", 0, 0)) {
+      if (chan->key_prot[0])
+        dprintf(DP_SERVER, "JOIN %s %s\n", chan->dname, chan->key_prot);
+      else
+        dprintf(DP_SERVER, "JOIN %s\n", chan->dname);
+    }
+  } else
+    remove_channel(chan);
   return ret;
 }
 
