@@ -9,7 +9,7 @@
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2024 Eggheads Development Team
+ * Copyright (C) 1999 - 2025 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -103,7 +103,7 @@ void tell_verbose_status(int);
 void tell_settings(int);
 int logmodes(char *);
 int isowner(char *);
-char *masktype(int);
+const char *masktype(int);
 char *maskname(int);
 void reaffirm_owners(void);
 void add_hq_user(void);
@@ -124,7 +124,7 @@ int check_dcc_attrs(struct userrec *, int);
 int check_dcc_chanattrs(struct userrec *, char *, int, int);
 int check_int_range(char *value, int min, int max);
 int stripmodes(char *);
-char *stripmasktype(int);
+const char *stripmasktype(int);
 char *check_validpass(struct userrec *, char *);
 void cmd_die(struct userrec *, int, char *);
 
@@ -226,7 +226,7 @@ void debug_mem_to_dcc(int);
 
 /* misc.c */
 int egg_strcatn(char *, const char *, size_t);
-int my_strcpy(char *, char *);
+int my_strcpy(char *, const char *);
 void putlog(int type, char *chname, const char *format, ...) ATTRIBUTE_FORMAT(printf,3,4);
 void check_logsize(void);
 void splitc(char *, char *, char);
@@ -309,6 +309,7 @@ int readtclprog(char *fname);
 
 /* tls.c */
 #ifdef TLS
+void verify_cert_expiry(int);
 int ssl_handshake(int, int, int, int, char *, IntFunc);
 char *ssl_fpconv(char *in, char *out);
 const char *ssl_getuid(int sock);
