@@ -4,7 +4,7 @@
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2024 Eggheads Development Team
+ * Copyright (C) 1999 - 2025 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -422,13 +422,11 @@ static int laston_unpack(struct userrec *u, struct user_entry *e)
 static int laston_pack(struct userrec *u, struct user_entry *e)
 {
   char work[1024];
-  long tv;
   struct laston_info *li;
   int l;
 
   li = (struct laston_info *) e->u.extra;
-  tv = li->laston;
-  l = sprintf(work, "%lu %s", tv, li->lastonplace);
+  l = sprintf(work, "%" PRId64 " %s", (int64_t) li->laston, li->lastonplace);
   e->u.list = user_malloc(sizeof(struct list_type));
   e->u.list->next = NULL;
   e->u.list->extra = user_malloc(l + 1);
@@ -441,11 +439,9 @@ static int laston_pack(struct userrec *u, struct user_entry *e)
 static int laston_write_userfile(FILE *f, struct userrec *u,
                                  struct user_entry *e)
 {
-  long tv;
   struct laston_info *li = (struct laston_info *) e->u.extra;
 
-  tv = li->laston;
-  if (fprintf(f, "--LASTON %lu %s\n", tv,
+  if (fprintf(f, "--LASTON %" PRId64 " %s\n", (int64_t) li->laston,
               li->lastonplace ? li->lastonplace : "") == EOF)
     return 0;
   return 1;
@@ -791,7 +787,7 @@ static int botaddr_tcl_set(Tcl_Interp * irp, struct userrec *u,
         bi->ssl |= TLS_BOT;
         if (argc == 5) {
           bi->ssl |= TLS_RELAY;
-        } 
+        }
       } else {
         bi->ssl &= ~TLS_BOT;
         if (argc == 5) {
